"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
// eslint-disable-next-line import/no-internal-modules
const summarizerNodeUtils_js_1 = require("../summary/summarizerNode/summarizerNodeUtils.js");
/**
 * These tests emulate the behavior that summarizeNode will use to build summary a handle id for each node in the summary
 * and test whether the path is built as expected. The motivation to add these tests is that the ids of data stores and DDSes can now be
 * special characters which must be dealt with caution when building ids of a summary tree.
 */
describe("Summary handle encoding works as expected", () => {
    it("Validate basic path append behavior", () => {
        const rootPath = summarizerNodeUtils_js_1.EscapedPath.create("");
        assert_1.strict.equal(rootPath.toString(), "");
        const childPath = summarizerNodeUtils_js_1.EscapedPath.create("childIdMock");
        assert_1.strict.equal(childPath.toString(), "childIdMock");
        const subChildPath = summarizerNodeUtils_js_1.EscapedPath.create("subChildIdMock");
        const completePathToChild = childPath.createChildPath(subChildPath);
        assert_1.strict.equal(completePathToChild.toString(), "childIdMock/.channels/subChildIdMock");
    });
    it("Validate basic path append behavior with special characters in path", () => {
        const parentPath = summarizerNodeUtils_js_1.EscapedPath.create("@");
        assert_1.strict.equal(parentPath.toString(), "%40");
        const childPath = summarizerNodeUtils_js_1.EscapedPath.create("&");
        assert_1.strict.equal(childPath.toString(), "%26");
        const completePath = parentPath.createChildPath(childPath);
        assert_1.strict.equal(completePath.toString(), "%40/.channels/%26");
    });
});
//# sourceMappingURL=summaryNodeUtils.spec.js.map