"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.EscapedPath = void 0;
const internal_1 = require("@fluidframework/runtime-definitions/internal");
/**
 * Class to build paths for nodes in a tree with escaped special characters
 */
class EscapedPath {
    constructor(path) {
        this.path = path;
    }
    /**
     * Creates and returns a new instance of this class.
     * @param path - Id or path part of a node
     */
    static create(path) {
        return new EscapedPath(encodeURIComponent(path));
    }
    toString() {
        return this.path;
    }
    /**
     * Creates and returns a new instance of this class for child of the current node.
     */
    createChildPath(childNodePath) {
        return new EscapedPath(`${this.path}/${encodeURIComponent(internal_1.channelsTreeName)}/${childNodePath.path}`);
    }
}
exports.EscapedPath = EscapedPath;
//# sourceMappingURL=summarizerNodeUtils.js.map